@@ -1,9 +1,10 @@
 from pathlib import Path
+from typing import Union
 import inspect
 import os
 
 
-def rel_to_abs(rel_path: str, parents=0, return_str=True, strict=False):
+def rel_to_abs(rel_path: Union[str, Path], parents=0, return_str=True, strict=False):
     """Return absolute path relative to the called file
     args:
         parent: <int> The number of times `f_back` will be calledd.
@@ -15,12 +16,12 @@ def rel_to_abs(rel_path: str, parents=0, return_str=True, strict=False):
             f = f.f_back
     current_path = Path(f.f_code.co_filename).parent
     pathlib_path = current_path / rel_path
-    pathlib_path =  pathlib_path.resolve(strict=strict)
+    pathlib_path = pathlib_path.resolve(strict=strict)
     if return_str:
         return str(pathlib_path)
     else:
         return pathlib_path
 
 
-def rel_path_join(*paths: str):
-    return rel_to_abs(os.path.join(*paths))
+def rel_path_join(*paths: Union[str, Path], return_str=True):
+    return rel_to_abs(os.path.join(*paths), parents=1, return_str=return_str)
