@@ -1,4 +1,4 @@
-if __name__ == "__main":
+if __name__ == "__main__":
     from sparrow.multiprocess.client import Client
     client = Client()
-    print(client.get_data())
+    print(client.get_dict_data())
