@@ -1,4 +1,4 @@
-if __name__ == "__main":
+if __name__ == "__main__":
     from sparrow.multiprocess.client import Client
     client = Client()
-    client.update_data({'a': 1, 'b': 2})
\ No newline at end of file
+    client.update_dict({'a': 1, 'b': 2})
\ No newline at end of file
